/**
 * Fusion Applications Environment Management API
 * Use the Fusion Applications Environment Management API to manage the environments where your Fusion Applications run. For more information, see the [Fusion Applications Environment Management documentation](/iaas/Content/Identity/fusion-applications/home.htm).
 * OpenAPI spec version: 20211201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { FusionApplicationsWaiter } from "./fusionapplications-waiter";
export declare enum FusionApplicationsApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FusionApplicationsClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FusionApplicationsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpOptions: any;
    targetService: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FusionApplicationsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FusionApplicationsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FusionApplicationsWaiter;
    /**
     * Moves a FusionEnvironment into a different compartment. When provided, If-Match is checked against ETag
     * values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeFusionEnvironmentCompartmentRequest
     * @return ChangeFusionEnvironmentCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ChangeFusionEnvironmentCompartment.ts.html |here} to see how to use ChangeFusionEnvironmentCompartment API.
     */
    changeFusionEnvironmentCompartment(changeFusionEnvironmentCompartmentRequest: requests.ChangeFusionEnvironmentCompartmentRequest): Promise<responses.ChangeFusionEnvironmentCompartmentResponse>;
    /**
     * Moves a FusionEnvironmentFamily into a different compartment. When provided, If-Match is checked against ETag
     * values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeFusionEnvironmentFamilyCompartmentRequest
     * @return ChangeFusionEnvironmentFamilyCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ChangeFusionEnvironmentFamilyCompartment.ts.html |here} to see how to use ChangeFusionEnvironmentFamilyCompartment API.
     */
    changeFusionEnvironmentFamilyCompartment(changeFusionEnvironmentFamilyCompartmentRequest: requests.ChangeFusionEnvironmentFamilyCompartmentRequest): Promise<responses.ChangeFusionEnvironmentFamilyCompartmentResponse>;
    /**
     * Creates a new DataMaskingActivity.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDataMaskingActivityRequest
     * @return CreateDataMaskingActivityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/CreateDataMaskingActivity.ts.html |here} to see how to use CreateDataMaskingActivity API.
     */
    createDataMaskingActivity(createDataMaskingActivityRequest: requests.CreateDataMaskingActivityRequest): Promise<responses.CreateDataMaskingActivityResponse>;
    /**
     * Creates a new FusionEnvironment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateFusionEnvironmentRequest
     * @return CreateFusionEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/CreateFusionEnvironment.ts.html |here} to see how to use CreateFusionEnvironment API.
     */
    createFusionEnvironment(createFusionEnvironmentRequest: requests.CreateFusionEnvironmentRequest): Promise<responses.CreateFusionEnvironmentResponse>;
    /**
     * Create a FusionEnvironment admin user
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateFusionEnvironmentAdminUserRequest
     * @return CreateFusionEnvironmentAdminUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/CreateFusionEnvironmentAdminUser.ts.html |here} to see how to use CreateFusionEnvironmentAdminUser API.
     */
    createFusionEnvironmentAdminUser(createFusionEnvironmentAdminUserRequest: requests.CreateFusionEnvironmentAdminUserRequest): Promise<responses.CreateFusionEnvironmentAdminUserResponse>;
    /**
     * Creates a new FusionEnvironmentFamily.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateFusionEnvironmentFamilyRequest
     * @return CreateFusionEnvironmentFamilyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/CreateFusionEnvironmentFamily.ts.html |here} to see how to use CreateFusionEnvironmentFamily API.
     */
    createFusionEnvironmentFamily(createFusionEnvironmentFamilyRequest: requests.CreateFusionEnvironmentFamilyRequest): Promise<responses.CreateFusionEnvironmentFamilyResponse>;
    /**
     * Creates a new RefreshActivity.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateRefreshActivityRequest
     * @return CreateRefreshActivityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/CreateRefreshActivity.ts.html |here} to see how to use CreateRefreshActivity API.
     */
    createRefreshActivity(createRefreshActivityRequest: requests.CreateRefreshActivityRequest): Promise<responses.CreateRefreshActivityResponse>;
    /**
     * Deletes the Fusion environment identified by it's OCID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteFusionEnvironmentRequest
     * @return DeleteFusionEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/DeleteFusionEnvironment.ts.html |here} to see how to use DeleteFusionEnvironment API.
     */
    deleteFusionEnvironment(deleteFusionEnvironmentRequest: requests.DeleteFusionEnvironmentRequest): Promise<responses.DeleteFusionEnvironmentResponse>;
    /**
     * Deletes the FusionEnvironment administrator user identified by the username.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteFusionEnvironmentAdminUserRequest
     * @return DeleteFusionEnvironmentAdminUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/DeleteFusionEnvironmentAdminUser.ts.html |here} to see how to use DeleteFusionEnvironmentAdminUser API.
     */
    deleteFusionEnvironmentAdminUser(deleteFusionEnvironmentAdminUserRequest: requests.DeleteFusionEnvironmentAdminUserRequest): Promise<responses.DeleteFusionEnvironmentAdminUserResponse>;
    /**
     * Deletes a FusionEnvironmentFamily resource by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteFusionEnvironmentFamilyRequest
     * @return DeleteFusionEnvironmentFamilyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/DeleteFusionEnvironmentFamily.ts.html |here} to see how to use DeleteFusionEnvironmentFamily API.
     */
    deleteFusionEnvironmentFamily(deleteFusionEnvironmentFamilyRequest: requests.DeleteFusionEnvironmentFamilyRequest): Promise<responses.DeleteFusionEnvironmentFamilyResponse>;
    /**
     * Gets a DataMaskingActivity by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataMaskingActivityRequest
     * @return GetDataMaskingActivityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetDataMaskingActivity.ts.html |here} to see how to use GetDataMaskingActivity API.
     */
    getDataMaskingActivity(getDataMaskingActivityRequest: requests.GetDataMaskingActivityRequest): Promise<responses.GetDataMaskingActivityResponse>;
    /**
     * Gets a FusionEnvironment by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetFusionEnvironmentRequest
     * @return GetFusionEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetFusionEnvironment.ts.html |here} to see how to use GetFusionEnvironment API.
     */
    getFusionEnvironment(getFusionEnvironmentRequest: requests.GetFusionEnvironmentRequest): Promise<responses.GetFusionEnvironmentResponse>;
    /**
     * Retrieves a fusion environment family identified by its OCID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetFusionEnvironmentFamilyRequest
     * @return GetFusionEnvironmentFamilyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetFusionEnvironmentFamily.ts.html |here} to see how to use GetFusionEnvironmentFamily API.
     */
    getFusionEnvironmentFamily(getFusionEnvironmentFamilyRequest: requests.GetFusionEnvironmentFamilyRequest): Promise<responses.GetFusionEnvironmentFamilyResponse>;
    /**
     * Gets the number of environments (usage) of each type in the fusion environment family, as well as the limit that's allowed to be created based on the group's associated subscriptions.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetFusionEnvironmentFamilyLimitsAndUsageRequest
     * @return GetFusionEnvironmentFamilyLimitsAndUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetFusionEnvironmentFamilyLimitsAndUsage.ts.html |here} to see how to use GetFusionEnvironmentFamilyLimitsAndUsage API.
     */
    getFusionEnvironmentFamilyLimitsAndUsage(getFusionEnvironmentFamilyLimitsAndUsageRequest: requests.GetFusionEnvironmentFamilyLimitsAndUsageRequest): Promise<responses.GetFusionEnvironmentFamilyLimitsAndUsageResponse>;
    /**
     * Gets the subscription details of an fusion environment family.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetFusionEnvironmentFamilySubscriptionDetailRequest
     * @return GetFusionEnvironmentFamilySubscriptionDetailResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetFusionEnvironmentFamilySubscriptionDetail.ts.html |here} to see how to use GetFusionEnvironmentFamilySubscriptionDetail API.
     */
    getFusionEnvironmentFamilySubscriptionDetail(getFusionEnvironmentFamilySubscriptionDetailRequest: requests.GetFusionEnvironmentFamilySubscriptionDetailRequest): Promise<responses.GetFusionEnvironmentFamilySubscriptionDetailResponse>;
    /**
     * Gets the status of a Fusion environment identified by its OCID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetFusionEnvironmentStatusRequest
     * @return GetFusionEnvironmentStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetFusionEnvironmentStatus.ts.html |here} to see how to use GetFusionEnvironmentStatus API.
     */
    getFusionEnvironmentStatus(getFusionEnvironmentStatusRequest: requests.GetFusionEnvironmentStatusRequest): Promise<responses.GetFusionEnvironmentStatusResponse>;
    /**
     * Gets a RefreshActivity by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetRefreshActivityRequest
     * @return GetRefreshActivityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetRefreshActivity.ts.html |here} to see how to use GetRefreshActivity API.
     */
    getRefreshActivity(getRefreshActivityRequest: requests.GetRefreshActivityRequest): Promise<responses.GetRefreshActivityResponse>;
    /**
     * Gets a ScheduledActivity by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetScheduledActivityRequest
     * @return GetScheduledActivityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetScheduledActivity.ts.html |here} to see how to use GetScheduledActivity API.
     */
    getScheduledActivity(getScheduledActivityRequest: requests.GetScheduledActivityRequest): Promise<responses.GetScheduledActivityResponse>;
    /**
     * Gets a Service Attachment by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetServiceAttachmentRequest
     * @return GetServiceAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetServiceAttachment.ts.html |here} to see how to use GetServiceAttachment API.
     */
    getServiceAttachment(getServiceAttachmentRequest: requests.GetServiceAttachmentRequest): Promise<responses.GetServiceAttachmentResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * List all FusionEnvironment admin users
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAdminUsersRequest
     * @return ListAdminUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListAdminUsers.ts.html |here} to see how to use ListAdminUsers API.
     */
    listAdminUsers(listAdminUsersRequest: requests.ListAdminUsersRequest): Promise<responses.ListAdminUsersResponse>;
    /**
     * Returns a list of DataMaskingActivities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataMaskingActivitiesRequest
     * @return ListDataMaskingActivitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListDataMaskingActivities.ts.html |here} to see how to use ListDataMaskingActivities API.
     */
    listDataMaskingActivities(listDataMaskingActivitiesRequest: requests.ListDataMaskingActivitiesRequest): Promise<responses.ListDataMaskingActivitiesResponse>;
    /**
     * Returns a list of FusionEnvironmentFamilies.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListFusionEnvironmentFamiliesRequest
     * @return ListFusionEnvironmentFamiliesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListFusionEnvironmentFamilies.ts.html |here} to see how to use ListFusionEnvironmentFamilies API.
     */
    listFusionEnvironmentFamilies(listFusionEnvironmentFamiliesRequest: requests.ListFusionEnvironmentFamiliesRequest): Promise<responses.ListFusionEnvironmentFamiliesResponse>;
    /**
     * Returns a list of FusionEnvironments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListFusionEnvironmentsRequest
     * @return ListFusionEnvironmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListFusionEnvironments.ts.html |here} to see how to use ListFusionEnvironments API.
     */
    listFusionEnvironments(listFusionEnvironmentsRequest: requests.ListFusionEnvironmentsRequest): Promise<responses.ListFusionEnvironmentsResponse>;
    /**
     * Returns a list of RefreshActivities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListRefreshActivitiesRequest
     * @return ListRefreshActivitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListRefreshActivities.ts.html |here} to see how to use ListRefreshActivities API.
     */
    listRefreshActivities(listRefreshActivitiesRequest: requests.ListRefreshActivitiesRequest): Promise<responses.ListRefreshActivitiesResponse>;
    /**
     * Returns a list of ScheduledActivities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListScheduledActivitiesRequest
     * @return ListScheduledActivitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListScheduledActivities.ts.html |here} to see how to use ListScheduledActivities API.
     */
    listScheduledActivities(listScheduledActivitiesRequest: requests.ListScheduledActivitiesRequest): Promise<responses.ListScheduledActivitiesResponse>;
    /**
     * Returns a list of service attachments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListServiceAttachmentsRequest
     * @return ListServiceAttachmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListServiceAttachments.ts.html |here} to see how to use ListServiceAttachments API.
     */
    listServiceAttachments(listServiceAttachmentsRequest: requests.ListServiceAttachmentsRequest): Promise<responses.ListServiceAttachmentsResponse>;
    /**
     * Gets available refresh time for this fusion environment
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTimeAvailableForRefreshesRequest
     * @return ListTimeAvailableForRefreshesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListTimeAvailableForRefreshes.ts.html |here} to see how to use ListTimeAvailableForRefreshes API.
     */
    listTimeAvailableForRefreshes(listTimeAvailableForRefreshesRequest: requests.ListTimeAvailableForRefreshesRequest): Promise<responses.ListTimeAvailableForRefreshesResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Resets the password of the Fusion Environment Administrator.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ResetFusionEnvironmentPasswordRequest
     * @return ResetFusionEnvironmentPasswordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/ResetFusionEnvironmentPassword.ts.html |here} to see how to use ResetFusionEnvironmentPassword API.
     */
    resetFusionEnvironmentPassword(resetFusionEnvironmentPasswordRequest: requests.ResetFusionEnvironmentPasswordRequest): Promise<responses.ResetFusionEnvironmentPasswordResponse>;
    /**
     * Updates the FusionEnvironment
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateFusionEnvironmentRequest
     * @return UpdateFusionEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/UpdateFusionEnvironment.ts.html |here} to see how to use UpdateFusionEnvironment API.
     */
    updateFusionEnvironment(updateFusionEnvironmentRequest: requests.UpdateFusionEnvironmentRequest): Promise<responses.UpdateFusionEnvironmentResponse>;
    /**
     * Updates the FusionEnvironmentFamily
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateFusionEnvironmentFamilyRequest
     * @return UpdateFusionEnvironmentFamilyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/fusionapps/UpdateFusionEnvironmentFamily.ts.html |here} to see how to use UpdateFusionEnvironmentFamily API.
     */
    updateFusionEnvironmentFamily(updateFusionEnvironmentFamilyRequest: requests.UpdateFusionEnvironmentFamilyRequest): Promise<responses.UpdateFusionEnvironmentFamilyResponse>;
}
