/**
 * Operations Insights API
 * Use the Operations Insights API to perform data extraction operations to obtain database
resource utilization, performance statistics, and reference information. For more information,
see [About Oracle Cloud Infrastructure Operations Insights](https://docs.cloud.oracle.com/en-us/iaas/operations-insights/doc/operations-insights.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { OperationsInsightsWaiter } from "./operationsinsights-waiter";
export declare enum OperationsInsightsApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OperationsInsightsClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OperationsInsightsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpOptions: any;
    targetService: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OperationsInsightsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OperationsInsightsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OperationsInsightsWaiter;
    /**
     * Add new members (e.g. databases and hosts) to an Exadata system in Operations Insights. Exadata-related metric collection and analysis will be started.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddExadataInsightMembersRequest
     * @return AddExadataInsightMembersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/AddExadataInsightMembers.ts.html |here} to see how to use AddExadataInsightMembers API.
     */
    addExadataInsightMembers(addExadataInsightMembersRequest: requests.AddExadataInsightMembersRequest): Promise<responses.AddExadataInsightMembersResponse>;
    /**
     * Moves a DatabaseInsight resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeDatabaseInsightCompartmentRequest
     * @return ChangeDatabaseInsightCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ChangeDatabaseInsightCompartment.ts.html |here} to see how to use ChangeDatabaseInsightCompartment API.
     */
    changeDatabaseInsightCompartment(changeDatabaseInsightCompartmentRequest: requests.ChangeDatabaseInsightCompartmentRequest): Promise<responses.ChangeDatabaseInsightCompartmentResponse>;
    /**
     * Moves a EnterpriseManagerBridge resource from one compartment to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeEnterpriseManagerBridgeCompartmentRequest
     * @return ChangeEnterpriseManagerBridgeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ChangeEnterpriseManagerBridgeCompartment.ts.html |here} to see how to use ChangeEnterpriseManagerBridgeCompartment API.
     */
    changeEnterpriseManagerBridgeCompartment(changeEnterpriseManagerBridgeCompartmentRequest: requests.ChangeEnterpriseManagerBridgeCompartmentRequest): Promise<responses.ChangeEnterpriseManagerBridgeCompartmentResponse>;
    /**
     * Moves an Exadata insight resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeExadataInsightCompartmentRequest
     * @return ChangeExadataInsightCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ChangeExadataInsightCompartment.ts.html |here} to see how to use ChangeExadataInsightCompartment API.
     */
    changeExadataInsightCompartment(changeExadataInsightCompartmentRequest: requests.ChangeExadataInsightCompartmentRequest): Promise<responses.ChangeExadataInsightCompartmentResponse>;
    /**
     * Moves a HostInsight resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeHostInsightCompartmentRequest
     * @return ChangeHostInsightCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ChangeHostInsightCompartment.ts.html |here} to see how to use ChangeHostInsightCompartment API.
     */
    changeHostInsightCompartment(changeHostInsightCompartmentRequest: requests.ChangeHostInsightCompartmentRequest): Promise<responses.ChangeHostInsightCompartmentResponse>;
    /**
     * Moves a private endpoint from one compartment to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeOperationsInsightsPrivateEndpointCompartmentRequest
     * @return ChangeOperationsInsightsPrivateEndpointCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ChangeOperationsInsightsPrivateEndpointCompartment.ts.html |here} to see how to use ChangeOperationsInsightsPrivateEndpointCompartment API.
     */
    changeOperationsInsightsPrivateEndpointCompartment(changeOperationsInsightsPrivateEndpointCompartmentRequest: requests.ChangeOperationsInsightsPrivateEndpointCompartmentRequest): Promise<responses.ChangeOperationsInsightsPrivateEndpointCompartmentResponse>;
    /**
     * Change the connection details of a co-managed  database insight. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangePeComanagedDatabaseInsightRequest
     * @return ChangePeComanagedDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ChangePeComanagedDatabaseInsight.ts.html |here} to see how to use ChangePeComanagedDatabaseInsight API.
     */
    changePeComanagedDatabaseInsight(changePeComanagedDatabaseInsightRequest: requests.ChangePeComanagedDatabaseInsightRequest): Promise<responses.ChangePeComanagedDatabaseInsightResponse>;
    /**
     * Create a AWR hub resource for the tenant in Operations Insights.
     * This resource will be created in root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAwrHubRequest
     * @return CreateAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/CreateAwrHub.ts.html |here} to see how to use CreateAwrHub API.
     */
    createAwrHub(createAwrHubRequest: requests.CreateAwrHubRequest): Promise<responses.CreateAwrHubResponse>;
    /**
     * Create a Database Insight resource for a database in Operations Insights. The database will be enabled in Operations Insights. Database metric collection and analysis will be started.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDatabaseInsightRequest
     * @return CreateDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/CreateDatabaseInsight.ts.html |here} to see how to use CreateDatabaseInsight API.
     */
    createDatabaseInsight(createDatabaseInsightRequest: requests.CreateDatabaseInsightRequest): Promise<responses.CreateDatabaseInsightResponse>;
    /**
     * Create a Enterprise Manager bridge in Operations Insights.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateEnterpriseManagerBridgeRequest
     * @return CreateEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/CreateEnterpriseManagerBridge.ts.html |here} to see how to use CreateEnterpriseManagerBridge API.
     */
    createEnterpriseManagerBridge(createEnterpriseManagerBridgeRequest: requests.CreateEnterpriseManagerBridgeRequest): Promise<responses.CreateEnterpriseManagerBridgeResponse>;
    /**
     * Create an Exadata insight resource for an Exadata system in Operations Insights. The Exadata system will be enabled in Operations Insights. Exadata-related metric collection and analysis will be started.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateExadataInsightRequest
     * @return CreateExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/CreateExadataInsight.ts.html |here} to see how to use CreateExadataInsight API.
     */
    createExadataInsight(createExadataInsightRequest: requests.CreateExadataInsightRequest): Promise<responses.CreateExadataInsightResponse>;
    /**
     * Create a Host Insight resource for a host in Operations Insights. The host will be enabled in Operations Insights. Host metric collection and analysis will be started.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateHostInsightRequest
     * @return CreateHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/CreateHostInsight.ts.html |here} to see how to use CreateHostInsight API.
     */
    createHostInsight(createHostInsightRequest: requests.CreateHostInsightRequest): Promise<responses.CreateHostInsightResponse>;
    /**
     * Create a private endpoint resource for the tenant in Operations Insights.
     * This resource will be created in customer compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOperationsInsightsPrivateEndpointRequest
     * @return CreateOperationsInsightsPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/CreateOperationsInsightsPrivateEndpoint.ts.html |here} to see how to use CreateOperationsInsightsPrivateEndpoint API.
     */
    createOperationsInsightsPrivateEndpoint(createOperationsInsightsPrivateEndpointRequest: requests.CreateOperationsInsightsPrivateEndpointRequest): Promise<responses.CreateOperationsInsightsPrivateEndpointResponse>;
    /**
     * Create a Operations Insights Warehouse resource for the tenant in Operations Insights. New ADW will be provisioned for this tenant.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment. If the 'opsi-warehouse-type'
     * header is passed to the API, a warehouse resource without ADW or Schema provisioning is created.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOperationsInsightsWarehouseRequest
     * @return CreateOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/CreateOperationsInsightsWarehouse.ts.html |here} to see how to use CreateOperationsInsightsWarehouse API.
     */
    createOperationsInsightsWarehouse(createOperationsInsightsWarehouseRequest: requests.CreateOperationsInsightsWarehouseRequest): Promise<responses.CreateOperationsInsightsWarehouseResponse>;
    /**
     * Create a Operations Insights Warehouse user resource for the tenant in Operations Insights.
     * This resource will be created in root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOperationsInsightsWarehouseUserRequest
     * @return CreateOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/CreateOperationsInsightsWarehouseUser.ts.html |here} to see how to use CreateOperationsInsightsWarehouseUser API.
     */
    createOperationsInsightsWarehouseUser(createOperationsInsightsWarehouseUserRequest: requests.CreateOperationsInsightsWarehouseUserRequest): Promise<responses.CreateOperationsInsightsWarehouseUserResponse>;
    /**
     * Deletes an AWR hub.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAwrHubRequest
     * @return DeleteAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DeleteAwrHub.ts.html |here} to see how to use DeleteAwrHub API.
     */
    deleteAwrHub(deleteAwrHubRequest: requests.DeleteAwrHubRequest): Promise<responses.DeleteAwrHubResponse>;
    /**
     * Deletes a database insight. The database insight will be deleted and cannot be enabled again.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDatabaseInsightRequest
     * @return DeleteDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DeleteDatabaseInsight.ts.html |here} to see how to use DeleteDatabaseInsight API.
     */
    deleteDatabaseInsight(deleteDatabaseInsightRequest: requests.DeleteDatabaseInsightRequest): Promise<responses.DeleteDatabaseInsightResponse>;
    /**
     * Deletes an Operations Insights Enterprise Manager bridge. If any database insight is still referencing this bridge, the operation will fail.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteEnterpriseManagerBridgeRequest
     * @return DeleteEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DeleteEnterpriseManagerBridge.ts.html |here} to see how to use DeleteEnterpriseManagerBridge API.
     */
    deleteEnterpriseManagerBridge(deleteEnterpriseManagerBridgeRequest: requests.DeleteEnterpriseManagerBridgeRequest): Promise<responses.DeleteEnterpriseManagerBridgeResponse>;
    /**
     * Deletes an Exadata insight. The Exadata insight will be deleted and cannot be enabled again.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteExadataInsightRequest
     * @return DeleteExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DeleteExadataInsight.ts.html |here} to see how to use DeleteExadataInsight API.
     */
    deleteExadataInsight(deleteExadataInsightRequest: requests.DeleteExadataInsightRequest): Promise<responses.DeleteExadataInsightResponse>;
    /**
     * Deletes a host insight. The host insight will be deleted and cannot be enabled again.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteHostInsightRequest
     * @return DeleteHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DeleteHostInsight.ts.html |here} to see how to use DeleteHostInsight API.
     */
    deleteHostInsight(deleteHostInsightRequest: requests.DeleteHostInsightRequest): Promise<responses.DeleteHostInsightResponse>;
    /**
     * Deletes a private endpoint.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOperationsInsightsPrivateEndpointRequest
     * @return DeleteOperationsInsightsPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DeleteOperationsInsightsPrivateEndpoint.ts.html |here} to see how to use DeleteOperationsInsightsPrivateEndpoint API.
     */
    deleteOperationsInsightsPrivateEndpoint(deleteOperationsInsightsPrivateEndpointRequest: requests.DeleteOperationsInsightsPrivateEndpointRequest): Promise<responses.DeleteOperationsInsightsPrivateEndpointResponse>;
    /**
     * Deletes an Operations Insights Warehouse. There is only expected to be 1 warehouse per tenant.
     * The warehouse is expected to be in the root compartment.
     * User must delete AWR Hub resource for this warehouse before calling this operation.
     * User must delete the warehouse users before calling this operation.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOperationsInsightsWarehouseRequest
     * @return DeleteOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DeleteOperationsInsightsWarehouse.ts.html |here} to see how to use DeleteOperationsInsightsWarehouse API.
     */
    deleteOperationsInsightsWarehouse(deleteOperationsInsightsWarehouseRequest: requests.DeleteOperationsInsightsWarehouseRequest): Promise<responses.DeleteOperationsInsightsWarehouseResponse>;
    /**
     * Deletes an Operations Insights Warehouse User.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOperationsInsightsWarehouseUserRequest
     * @return DeleteOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DeleteOperationsInsightsWarehouseUser.ts.html |here} to see how to use DeleteOperationsInsightsWarehouseUser API.
     */
    deleteOperationsInsightsWarehouseUser(deleteOperationsInsightsWarehouseUserRequest: requests.DeleteOperationsInsightsWarehouseUserRequest): Promise<responses.DeleteOperationsInsightsWarehouseUserResponse>;
    /**
     * Disables a database in Operations Insights. Database metric collection and analysis will be stopped.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableDatabaseInsightRequest
     * @return DisableDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DisableDatabaseInsight.ts.html |here} to see how to use DisableDatabaseInsight API.
     */
    disableDatabaseInsight(disableDatabaseInsightRequest: requests.DisableDatabaseInsightRequest): Promise<responses.DisableDatabaseInsightResponse>;
    /**
     * Disables an Exadata system in Operations Insights. Exadata-related metric collection and analysis will be stopped.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableExadataInsightRequest
     * @return DisableExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DisableExadataInsight.ts.html |here} to see how to use DisableExadataInsight API.
     */
    disableExadataInsight(disableExadataInsightRequest: requests.DisableExadataInsightRequest): Promise<responses.DisableExadataInsightResponse>;
    /**
     * Disables a host in Operations Insights. Host metric collection and analysis will be stopped.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableHostInsightRequest
     * @return DisableHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DisableHostInsight.ts.html |here} to see how to use DisableHostInsight API.
     */
    disableHostInsight(disableHostInsightRequest: requests.DisableHostInsightRequest): Promise<responses.DisableHostInsightResponse>;
    /**
     * Download the ADW wallet for Operations Insights Warehouse using which the Hub data is exposed.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DownloadOperationsInsightsWarehouseWalletRequest
     * @return DownloadOperationsInsightsWarehouseWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/DownloadOperationsInsightsWarehouseWallet.ts.html |here} to see how to use DownloadOperationsInsightsWarehouseWallet API.
     */
    downloadOperationsInsightsWarehouseWallet(downloadOperationsInsightsWarehouseWalletRequest: requests.DownloadOperationsInsightsWarehouseWalletRequest): Promise<responses.DownloadOperationsInsightsWarehouseWalletResponse>;
    /**
     * Enables a database in Operations Insights. Database metric collection and analysis will be started.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableDatabaseInsightRequest
     * @return EnableDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/EnableDatabaseInsight.ts.html |here} to see how to use EnableDatabaseInsight API.
     */
    enableDatabaseInsight(enableDatabaseInsightRequest: requests.EnableDatabaseInsightRequest): Promise<responses.EnableDatabaseInsightResponse>;
    /**
     * Enables an Exadata system in Operations Insights. Exadata-related metric collection and analysis will be started.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableExadataInsightRequest
     * @return EnableExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/EnableExadataInsight.ts.html |here} to see how to use EnableExadataInsight API.
     */
    enableExadataInsight(enableExadataInsightRequest: requests.EnableExadataInsightRequest): Promise<responses.EnableExadataInsightResponse>;
    /**
     * Enables a host in Operations Insights. Host metric collection and analysis will be started.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableHostInsightRequest
     * @return EnableHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/EnableHostInsight.ts.html |here} to see how to use EnableHostInsight API.
     */
    enableHostInsight(enableHostInsightRequest: requests.EnableHostInsightRequest): Promise<responses.EnableHostInsightResponse>;
    /**
     * Gets the AWR report for the specified database.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrDatabaseReportRequest
     * @return GetAwrDatabaseReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetAwrDatabaseReport.ts.html |here} to see how to use GetAwrDatabaseReport API.
     */
    getAwrDatabaseReport(getAwrDatabaseReportRequest: requests.GetAwrDatabaseReportRequest): Promise<responses.GetAwrDatabaseReportResponse>;
    /**
     * Gets the SQL health check report for one SQL of the specified database.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrDatabaseSqlReportRequest
     * @return GetAwrDatabaseSqlReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetAwrDatabaseSqlReport.ts.html |here} to see how to use GetAwrDatabaseSqlReport API.
     */
    getAwrDatabaseSqlReport(getAwrDatabaseSqlReportRequest: requests.GetAwrDatabaseSqlReportRequest): Promise<responses.GetAwrDatabaseSqlReportResponse>;
    /**
     * Gets details of an AWR hub.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrHubRequest
     * @return GetAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetAwrHub.ts.html |here} to see how to use GetAwrHub API.
     */
    getAwrHub(getAwrHubRequest: requests.GetAwrHubRequest): Promise<responses.GetAwrHubResponse>;
    /**
     * Gets the AWR report for the specified source database in the AWR hub. The difference between the timeGreaterThanOrEqualTo and timeLessThanOrEqualTo should not be greater than 7 days.
     * Either beginSnapshotIdentifierGreaterThanOrEqualTo & endSnapshotIdentifierLessThanOrEqualTo params Or timeGreaterThanOrEqualTo & timeLessThanOrEqualTo params are required.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrReportRequest
     * @return GetAwrReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetAwrReport.ts.html |here} to see how to use GetAwrReport API.
     */
    getAwrReport(getAwrReportRequest: requests.GetAwrReportRequest): Promise<responses.GetAwrReportResponse>;
    /**
     * Gets details of a database insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDatabaseInsightRequest
     * @return GetDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetDatabaseInsight.ts.html |here} to see how to use GetDatabaseInsight API.
     */
    getDatabaseInsight(getDatabaseInsightRequest: requests.GetDatabaseInsightRequest): Promise<responses.GetDatabaseInsightResponse>;
    /**
     * Gets details of an Operations Insights Enterprise Manager bridge.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetEnterpriseManagerBridgeRequest
     * @return GetEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetEnterpriseManagerBridge.ts.html |here} to see how to use GetEnterpriseManagerBridge API.
     */
    getEnterpriseManagerBridge(getEnterpriseManagerBridgeRequest: requests.GetEnterpriseManagerBridgeRequest): Promise<responses.GetEnterpriseManagerBridgeResponse>;
    /**
     * Gets details of an Exadata insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetExadataInsightRequest
     * @return GetExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetExadataInsight.ts.html |here} to see how to use GetExadataInsight API.
     */
    getExadataInsight(getExadataInsightRequest: requests.GetExadataInsightRequest): Promise<responses.GetExadataInsightResponse>;
    /**
     * Gets details of a host insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetHostInsightRequest
     * @return GetHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetHostInsight.ts.html |here} to see how to use GetHostInsight API.
     */
    getHostInsight(getHostInsightRequest: requests.GetHostInsightRequest): Promise<responses.GetHostInsightResponse>;
    /**
     * Gets the details of the specified private endpoint.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOperationsInsightsPrivateEndpointRequest
     * @return GetOperationsInsightsPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetOperationsInsightsPrivateEndpoint.ts.html |here} to see how to use GetOperationsInsightsPrivateEndpoint API.
     */
    getOperationsInsightsPrivateEndpoint(getOperationsInsightsPrivateEndpointRequest: requests.GetOperationsInsightsPrivateEndpointRequest): Promise<responses.GetOperationsInsightsPrivateEndpointResponse>;
    /**
     * Gets details of an Operations Insights Warehouse.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOperationsInsightsWarehouseRequest
     * @return GetOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetOperationsInsightsWarehouse.ts.html |here} to see how to use GetOperationsInsightsWarehouse API.
     */
    getOperationsInsightsWarehouse(getOperationsInsightsWarehouseRequest: requests.GetOperationsInsightsWarehouseRequest): Promise<responses.GetOperationsInsightsWarehouseResponse>;
    /**
     * Gets details of an Operations Insights Warehouse User.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOperationsInsightsWarehouseUserRequest
     * @return GetOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetOperationsInsightsWarehouseUser.ts.html |here} to see how to use GetOperationsInsightsWarehouseUser API.
     */
    getOperationsInsightsWarehouseUser(getOperationsInsightsWarehouseUserRequest: requests.GetOperationsInsightsWarehouseUserRequest): Promise<responses.GetOperationsInsightsWarehouseUserResponse>;
    /**
     * Gets details of an OPSI data object.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOpsiDataObjectRequest
     * @return GetOpsiDataObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetOpsiDataObject.ts.html |here} to see how to use GetOpsiDataObject API.
     */
    getOpsiDataObject(getOpsiDataObjectRequest: requests.GetOpsiDataObjectRequest): Promise<responses.GetOpsiDataObjectResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * This is a generic ingest endpoint for all database configuration metrics.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestDatabaseConfigurationRequest
     * @return IngestDatabaseConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/IngestDatabaseConfiguration.ts.html |here} to see how to use IngestDatabaseConfiguration API.
     */
    ingestDatabaseConfiguration(ingestDatabaseConfigurationRequest: requests.IngestDatabaseConfigurationRequest): Promise<responses.IngestDatabaseConfigurationResponse>;
    /**
     * This is a generic ingest endpoint for all the host configuration metrics
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestHostConfigurationRequest
     * @return IngestHostConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/IngestHostConfiguration.ts.html |here} to see how to use IngestHostConfiguration API.
     */
    ingestHostConfiguration(ingestHostConfigurationRequest: requests.IngestHostConfigurationRequest): Promise<responses.IngestHostConfigurationResponse>;
    /**
     * This is a generic ingest endpoint for all the host performance metrics
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestHostMetricsRequest
     * @return IngestHostMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/IngestHostMetrics.ts.html |here} to see how to use IngestHostMetrics API.
     */
    ingestHostMetrics(ingestHostMetricsRequest: requests.IngestHostMetricsRequest): Promise<responses.IngestHostMetricsResponse>;
    /**
     * The sqlbucket endpoint takes in a JSON payload, persists it in Operations Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestSqlBucketRequest
     * @return IngestSqlBucketResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/IngestSqlBucket.ts.html |here} to see how to use IngestSqlBucket API.
     */
    ingestSqlBucket(ingestSqlBucketRequest: requests.IngestSqlBucketRequest): Promise<responses.IngestSqlBucketResponse>;
    /**
     * The SqlPlanLines endpoint takes in a JSON payload, persists it in Operation Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestSqlPlanLinesRequest
     * @return IngestSqlPlanLinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/IngestSqlPlanLines.ts.html |here} to see how to use IngestSqlPlanLines API.
     */
    ingestSqlPlanLines(ingestSqlPlanLinesRequest: requests.IngestSqlPlanLinesRequest): Promise<responses.IngestSqlPlanLinesResponse>;
    /**
     * The SQL Stats endpoint takes in a JSON payload, persists it in Operations Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestSqlStatsRequest
     * @return IngestSqlStatsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/IngestSqlStats.ts.html |here} to see how to use IngestSqlStats API.
     */
    ingestSqlStats(ingestSqlStatsRequest: requests.IngestSqlStatsRequest): Promise<responses.IngestSqlStatsResponse>;
    /**
     * The SqlText endpoint takes in a JSON payload, persists it in Operation Insights ingest pipeline.
     * Either databaseId or id must be specified.
     * Disclaimer: SQL text being uploaded explicitly via APIs is not masked. Any sensitive literals contained in the sqlFullText column should be masked prior to ingestion.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestSqlTextRequest
     * @return IngestSqlTextResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/IngestSqlText.ts.html |here} to see how to use IngestSqlText API.
     */
    ingestSqlText(ingestSqlTextRequest: requests.IngestSqlTextRequest): Promise<responses.IngestSqlTextResponse>;
    /**
     * Lists AWR snapshots for the specified database in the AWR.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrDatabaseSnapshotsRequest
     * @return ListAwrDatabaseSnapshotsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListAwrDatabaseSnapshots.ts.html |here} to see how to use ListAwrDatabaseSnapshots API.
     */
    listAwrDatabaseSnapshots(listAwrDatabaseSnapshotsRequest: requests.ListAwrDatabaseSnapshotsRequest): Promise<responses.ListAwrDatabaseSnapshotsResponse>;
    /**
     * Gets the list of databases and their snapshot summary details available in the AWRHub.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrDatabasesRequest
     * @return ListAwrDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListAwrDatabases.ts.html |here} to see how to use ListAwrDatabases API.
     */
    listAwrDatabases(listAwrDatabasesRequest: requests.ListAwrDatabasesRequest): Promise<responses.ListAwrDatabasesResponse>;
    /**
     * Gets a list of AWR hubs. Either compartmentId or id must be specified. All these resources are expected to be in root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrHubsRequest
     * @return ListAwrHubsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListAwrHubs.ts.html |here} to see how to use ListAwrHubs API.
     */
    listAwrHubs(listAwrHubsRequest: requests.ListAwrHubsRequest): Promise<responses.ListAwrHubsResponse>;
    /**
     * Lists AWR snapshots for the specified source database in the AWR hub. The difference between the timeGreaterThanOrEqualTo and timeLessThanOrEqualTo should not exceed an elapsed range of 1 day.
     * The timeGreaterThanOrEqualTo & timeLessThanOrEqualTo params are optional. If these params are not provided, by default last 1 day snapshots will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrSnapshotsRequest
     * @return ListAwrSnapshotsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListAwrSnapshots.ts.html |here} to see how to use ListAwrSnapshots API.
     */
    listAwrSnapshots(listAwrSnapshotsRequest: requests.ListAwrSnapshotsRequest): Promise<responses.ListAwrSnapshotsResponse>;
    /**
     * Gets a list of database insight configurations based on the query parameters specified. Either compartmentId or databaseInsightId query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of database insight configurations in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDatabaseConfigurationsRequest
     * @return ListDatabaseConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListDatabaseConfigurations.ts.html |here} to see how to use ListDatabaseConfigurations API.
     */
    listDatabaseConfigurations(listDatabaseConfigurationsRequest: requests.ListDatabaseConfigurationsRequest): Promise<responses.ListDatabaseConfigurationsResponse>;
    /**
     * Gets a list of database insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of database insights in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDatabaseInsightsRequest
     * @return ListDatabaseInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListDatabaseInsights.ts.html |here} to see how to use ListDatabaseInsights API.
     */
    listDatabaseInsights(listDatabaseInsightsRequest: requests.ListDatabaseInsightsRequest): Promise<responses.ListDatabaseInsightsResponse>;
    /**
     * Gets a list of Operations Insights Enterprise Manager bridges. Either compartmentId or id must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of bridges in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListEnterpriseManagerBridgesRequest
     * @return ListEnterpriseManagerBridgesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListEnterpriseManagerBridges.ts.html |here} to see how to use ListEnterpriseManagerBridges API.
     */
    listEnterpriseManagerBridges(listEnterpriseManagerBridgesRequest: requests.ListEnterpriseManagerBridgesRequest): Promise<responses.ListEnterpriseManagerBridgesResponse>;
    /**
     * Gets a list of exadata insight configurations. Either compartmentId or exadataInsightsId query parameter must be specified.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListExadataConfigurationsRequest
     * @return ListExadataConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListExadataConfigurations.ts.html |here} to see how to use ListExadataConfigurations API.
     */
    listExadataConfigurations(listExadataConfigurationsRequest: requests.ListExadataConfigurationsRequest): Promise<responses.ListExadataConfigurationsResponse>;
    /**
     * Gets a list of Exadata insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of Exadata insights in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListExadataInsightsRequest
     * @return ListExadataInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListExadataInsights.ts.html |here} to see how to use ListExadataInsights API.
     */
    listExadataInsights(listExadataInsightsRequest: requests.ListExadataInsightsRequest): Promise<responses.ListExadataInsightsResponse>;
    /**
     * Gets a list of host insight configurations based on the query parameters specified. Either compartmentId or hostInsightId query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of host insight configurations in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListHostConfigurationsRequest
     * @return ListHostConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListHostConfigurations.ts.html |here} to see how to use ListHostConfigurations API.
     */
    listHostConfigurations(listHostConfigurationsRequest: requests.ListHostConfigurationsRequest): Promise<responses.ListHostConfigurationsResponse>;
    /**
     * Gets a list of host insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of host insights in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListHostInsightsRequest
     * @return ListHostInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListHostInsights.ts.html |here} to see how to use ListHostInsights API.
     */
    listHostInsights(listHostInsightsRequest: requests.ListHostInsightsRequest): Promise<responses.ListHostInsightsResponse>;
    /**
     * Get a list of hosted entities details.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListHostedEntitiesRequest
     * @return ListHostedEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListHostedEntities.ts.html |here} to see how to use ListHostedEntities API.
     */
    listHostedEntities(listHostedEntitiesRequest: requests.ListHostedEntitiesRequest): Promise<responses.ListHostedEntitiesResponse>;
    /**
     * Gets a list of agent entities available to add a new hostInsight.  An agent entity is \"available\"
     * and will be shown if all the following conditions are true:
     *    1.  The agent OCID is not already being used for an existing hostInsight.
     *    2.  The agent availabilityStatus = 'ACTIVE'
     *    3.  The agent lifecycleState = 'ACTIVE'
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListImportableAgentEntitiesRequest
     * @return ListImportableAgentEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListImportableAgentEntities.ts.html |here} to see how to use ListImportableAgentEntities API.
     */
    listImportableAgentEntities(listImportableAgentEntitiesRequest: requests.ListImportableAgentEntitiesRequest): Promise<responses.ListImportableAgentEntitiesResponse>;
    /**
     * Gets a list of importable entities for an Operations Insights Enterprise Manager bridge that have not been imported before.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListImportableEnterpriseManagerEntitiesRequest
     * @return ListImportableEnterpriseManagerEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListImportableEnterpriseManagerEntities.ts.html |here} to see how to use ListImportableEnterpriseManagerEntities API.
     */
    listImportableEnterpriseManagerEntities(listImportableEnterpriseManagerEntitiesRequest: requests.ListImportableEnterpriseManagerEntitiesRequest): Promise<responses.ListImportableEnterpriseManagerEntitiesResponse>;
    /**
     * Gets a list of Operation Insights private endpoints.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOperationsInsightsPrivateEndpointsRequest
     * @return ListOperationsInsightsPrivateEndpointsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListOperationsInsightsPrivateEndpoints.ts.html |here} to see how to use ListOperationsInsightsPrivateEndpoints API.
     */
    listOperationsInsightsPrivateEndpoints(listOperationsInsightsPrivateEndpointsRequest: requests.ListOperationsInsightsPrivateEndpointsRequest): Promise<responses.ListOperationsInsightsPrivateEndpointsResponse>;
    /**
     * Gets a list of Operations Insights Warehouse users. Either compartmentId or id must be specified. All these resources are expected to be in root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOperationsInsightsWarehouseUsersRequest
     * @return ListOperationsInsightsWarehouseUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListOperationsInsightsWarehouseUsers.ts.html |here} to see how to use ListOperationsInsightsWarehouseUsers API.
     */
    listOperationsInsightsWarehouseUsers(listOperationsInsightsWarehouseUsersRequest: requests.ListOperationsInsightsWarehouseUsersRequest): Promise<responses.ListOperationsInsightsWarehouseUsersResponse>;
    /**
     * Gets a list of Operations Insights warehouses. Either compartmentId or id must be specified.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOperationsInsightsWarehousesRequest
     * @return ListOperationsInsightsWarehousesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListOperationsInsightsWarehouses.ts.html |here} to see how to use ListOperationsInsightsWarehouses API.
     */
    listOperationsInsightsWarehouses(listOperationsInsightsWarehousesRequest: requests.ListOperationsInsightsWarehousesRequest): Promise<responses.ListOperationsInsightsWarehousesResponse>;
    /**
     * Gets a list of OPSI data objects based on the query parameters specified. CompartmentId id query parameter must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOpsiDataObjectsRequest
     * @return ListOpsiDataObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListOpsiDataObjects.ts.html |here} to see how to use ListOpsiDataObjects API.
     */
    listOpsiDataObjects(listOpsiDataObjectsRequest: requests.ListOpsiDataObjectsRequest): Promise<responses.ListOpsiDataObjectsResponse>;
    /**
     * Query SQL Warehouse to list the plan xml for a given SQL execution plan. This returns a SqlPlanCollection object, but is currently limited to a single plan.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSqlPlansRequest
     * @return ListSqlPlansResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListSqlPlans.ts.html |here} to see how to use ListSqlPlans API.
     */
    listSqlPlans(listSqlPlansRequest: requests.ListSqlPlansRequest): Promise<responses.ListSqlPlansResponse>;
    /**
     * Search SQL by SQL Identifier across databases in a compartment and in all sub-compartments if specified.
     * And get the SQL Text and the details of the databases executing the SQL for a given time period.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSqlSearchesRequest
     * @return ListSqlSearchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListSqlSearches.ts.html |here} to see how to use ListSqlSearches API.
     */
    listSqlSearches(listSqlSearchesRequest: requests.ListSqlSearchesRequest): Promise<responses.ListSqlSearchesResponse>;
    /**
     * Query SQL Warehouse to get the full SQL Text for a SQL in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSqlTextsRequest
     * @return ListSqlTextsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListSqlTexts.ts.html |here} to see how to use ListSqlTexts API.
     */
    listSqlTexts(listSqlTextsRequest: requests.ListSqlTextsRequest): Promise<responses.ListSqlTextsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment. Either compartmentId or id must be specified. Only one of id, resourceId or relatedResourceId can be specified optionally.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Queries an OPSI data object with the inputs provided and sends the result set back. Either analysisTimeInterval
     * or timeIntervalStart and timeIntervalEnd parameters need to be passed as well.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param QueryOpsiDataObjectDataRequest
     * @return QueryOpsiDataObjectDataResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/QueryOpsiDataObjectData.ts.html |here} to see how to use QueryOpsiDataObjectData API.
     */
    queryOpsiDataObjectData(queryOpsiDataObjectDataRequest: requests.QueryOpsiDataObjectDataRequest): Promise<responses.QueryOpsiDataObjectDataResponse>;
    /**
     * Rotate the ADW wallet for Operations Insights Warehouse using which the Hub data is exposed.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RotateOperationsInsightsWarehouseWalletRequest
     * @return RotateOperationsInsightsWarehouseWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/RotateOperationsInsightsWarehouseWallet.ts.html |here} to see how to use RotateOperationsInsightsWarehouseWallet API.
     */
    rotateOperationsInsightsWarehouseWallet(rotateOperationsInsightsWarehouseWalletRequest: requests.RotateOperationsInsightsWarehouseWalletRequest): Promise<responses.RotateOperationsInsightsWarehouseWalletResponse>;
    /**
     * Summarizes the AWR CPU resource limits and metrics for the specified database in AWR.
     * Based on the time range provided as part of query param, the metrics points will be returned in the response as below.
     * - if time range is <=7 days then the metrics points will be for every MINUTES
     * - if time range is <=2 hours then the metrics points will be for every 10 SECONDS
     * - if time range is >7 days then the metrics points will be for every HOUR.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseCpuUsagesRequest
     * @return SummarizeAwrDatabaseCpuUsagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrDatabaseCpuUsages.ts.html |here} to see how to use SummarizeAwrDatabaseCpuUsages API.
     */
    summarizeAwrDatabaseCpuUsages(summarizeAwrDatabaseCpuUsagesRequest: requests.SummarizeAwrDatabaseCpuUsagesRequest): Promise<responses.SummarizeAwrDatabaseCpuUsagesResponse>;
    /**
     * Summarizes the metric samples for the specified database in the AWR. The metric samples are summarized based on the Time dimension for each metric.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseMetricsRequest
     * @return SummarizeAwrDatabaseMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrDatabaseMetrics.ts.html |here} to see how to use SummarizeAwrDatabaseMetrics API.
     */
    summarizeAwrDatabaseMetrics(summarizeAwrDatabaseMetricsRequest: requests.SummarizeAwrDatabaseMetricsRequest): Promise<responses.SummarizeAwrDatabaseMetricsResponse>;
    /**
     * Summarizes the database parameter change history for one database parameter of the specified database in AWR. One change history record contains
     * the previous value, the changed value, and the corresponding time range. If the database parameter value was changed multiple times within the time range, then multiple change history records are created for the same parameter.
     * Note that this API only returns information on change history details for one database parameter.
     * To get a list of all the database parameters whose values were changed during a specified time range, use the following API endpoint:
     * /awrHubs/{awrHubId}/awrDbParameters?awrSourceDatabaseIdentifier={awrSourceDbId}
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseParameterChangesRequest
     * @return SummarizeAwrDatabaseParameterChangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrDatabaseParameterChanges.ts.html |here} to see how to use SummarizeAwrDatabaseParameterChanges API.
     */
    summarizeAwrDatabaseParameterChanges(summarizeAwrDatabaseParameterChangesRequest: requests.SummarizeAwrDatabaseParameterChangesRequest): Promise<responses.SummarizeAwrDatabaseParameterChangesResponse>;
    /**
       * Summarizes the database parameter history for the specified database in AWR. This includes the list of database
  * parameters, with information on whether the parameter values were modified within the query time range. Note that
  * each database parameter is only listed once. Depending on the optional query parameters, the returned summary gets all the database parameters, which include:
  * <p>
  Queryparam (valueChanged =\"Y\") - Each parameter whose value was changed during the time range, \"isChanged : true\" in response for the DB params.
  * Queryparam (valueChanged =\"N\") - Each parameter whose value was unchanged during the time range, \"isChanged : false\" in response for the DB params.
  * Queryparam (valueChanged =\"Y\"  and valueModified = \"SYSTEM_MOD\") - Each parameter whose value was changed at the system level during the time range, \"isChanged : true\" & \"valueModified : SYSTEM_MOD\" in response for the DB params.
  * Queryparam (valueChanged =\"N\" and  valueDefault = \"FALSE\") - Each parameter whose value was unchanged during the time range, however, the value is not the default value, \"isChanged : true\" & \"isDefault : false\" in response for the DB params.
  * <p>
  Note that this API does not return information on the number of times each database parameter has been changed within the time range. To get the database parameter value change history for a specific parameter, use the following API endpoint:
  * /awrHubs/{awrHubId}/awrDbParameterChanges?awrSourceDatabaseIdentifier={awrSourceDbId}
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param SummarizeAwrDatabaseParametersRequest
       * @return SummarizeAwrDatabaseParametersResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrDatabaseParameters.ts.html |here} to see how to use SummarizeAwrDatabaseParameters API.
       */
    summarizeAwrDatabaseParameters(summarizeAwrDatabaseParametersRequest: requests.SummarizeAwrDatabaseParametersRequest): Promise<responses.SummarizeAwrDatabaseParametersResponse>;
    /**
     * Summarizes the AWR snapshot ranges that contain continuous snapshots, for the specified AWRHub.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseSnapshotRangesRequest
     * @return SummarizeAwrDatabaseSnapshotRangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrDatabaseSnapshotRanges.ts.html |here} to see how to use SummarizeAwrDatabaseSnapshotRanges API.
     */
    summarizeAwrDatabaseSnapshotRanges(summarizeAwrDatabaseSnapshotRangesRequest: requests.SummarizeAwrDatabaseSnapshotRangesRequest): Promise<responses.SummarizeAwrDatabaseSnapshotRangesResponse>;
    /**
     * Summarizes the AWR SYSSTAT sample data for the specified database in AWR. The statistical data is summarized based on the Time dimension for each statistic.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseSysstatsRequest
     * @return SummarizeAwrDatabaseSysstatsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrDatabaseSysstats.ts.html |here} to see how to use SummarizeAwrDatabaseSysstats API.
     */
    summarizeAwrDatabaseSysstats(summarizeAwrDatabaseSysstatsRequest: requests.SummarizeAwrDatabaseSysstatsRequest): Promise<responses.SummarizeAwrDatabaseSysstatsResponse>;
    /**
     * Summarizes the AWR top wait events.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseTopWaitEventsRequest
     * @return SummarizeAwrDatabaseTopWaitEventsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrDatabaseTopWaitEvents.ts.html |here} to see how to use SummarizeAwrDatabaseTopWaitEvents API.
     */
    summarizeAwrDatabaseTopWaitEvents(summarizeAwrDatabaseTopWaitEventsRequest: requests.SummarizeAwrDatabaseTopWaitEventsRequest): Promise<responses.SummarizeAwrDatabaseTopWaitEventsResponse>;
    /**
     * Summarizes AWR wait event data into value buckets and frequency, for the specified database in the AWR.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseWaitEventBucketsRequest
     * @return SummarizeAwrDatabaseWaitEventBucketsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrDatabaseWaitEventBuckets.ts.html |here} to see how to use SummarizeAwrDatabaseWaitEventBuckets API.
     */
    summarizeAwrDatabaseWaitEventBuckets(summarizeAwrDatabaseWaitEventBucketsRequest: requests.SummarizeAwrDatabaseWaitEventBucketsRequest): Promise<responses.SummarizeAwrDatabaseWaitEventBucketsResponse>;
    /**
     * Summarizes the AWR wait event sample data for the specified database in the AWR. The event data is summarized based on the Time dimension for each event.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseWaitEventsRequest
     * @return SummarizeAwrDatabaseWaitEventsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrDatabaseWaitEvents.ts.html |here} to see how to use SummarizeAwrDatabaseWaitEvents API.
     */
    summarizeAwrDatabaseWaitEvents(summarizeAwrDatabaseWaitEventsRequest: requests.SummarizeAwrDatabaseWaitEventsRequest): Promise<responses.SummarizeAwrDatabaseWaitEventsResponse>;
    /**
     * Gets a list of summary of AWR Sources.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrSourcesSummariesRequest
     * @return SummarizeAwrSourcesSummariesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeAwrSourcesSummaries.ts.html |here} to see how to use SummarizeAwrSourcesSummaries API.
     */
    summarizeAwrSourcesSummaries(summarizeAwrSourcesSummariesRequest: requests.SummarizeAwrSourcesSummariesRequest): Promise<responses.SummarizeAwrSourcesSummariesResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity, baseCapacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceCapacityTrendRequest
     * @return SummarizeDatabaseInsightResourceCapacityTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeDatabaseInsightResourceCapacityTrend.ts.html |here} to see how to use SummarizeDatabaseInsightResourceCapacityTrend API.
     */
    summarizeDatabaseInsightResourceCapacityTrend(summarizeDatabaseInsightResourceCapacityTrendRequest: requests.SummarizeDatabaseInsightResourceCapacityTrendRequest): Promise<responses.SummarizeDatabaseInsightResourceCapacityTrendResponse>;
    /**
     * Get Forecast predictions for CPU and Storage resources since a time in the past.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceForecastTrendRequest
     * @return SummarizeDatabaseInsightResourceForecastTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeDatabaseInsightResourceForecastTrend.ts.html |here} to see how to use SummarizeDatabaseInsightResourceForecastTrend API.
     */
    summarizeDatabaseInsightResourceForecastTrend(summarizeDatabaseInsightResourceForecastTrendRequest: requests.SummarizeDatabaseInsightResourceForecastTrendRequest): Promise<responses.SummarizeDatabaseInsightResourceForecastTrendResponse>;
    /**
     * Lists the Resource statistics (usage,capacity, usage change percent, utilization percent, base capacity, isAutoScalingEnabled)
     * for each database filtered by utilization level in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceStatisticsRequest
     * @return SummarizeDatabaseInsightResourceStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeDatabaseInsightResourceStatistics.ts.html |here} to see how to use SummarizeDatabaseInsightResourceStatistics API.
     */
    summarizeDatabaseInsightResourceStatistics(summarizeDatabaseInsightResourceStatisticsRequest: requests.SummarizeDatabaseInsightResourceStatisticsRequest): Promise<responses.SummarizeDatabaseInsightResourceStatisticsResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per database within the specified time period.
     * For each database, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceUsageRequest
     * @return SummarizeDatabaseInsightResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeDatabaseInsightResourceUsage.ts.html |here} to see how to use SummarizeDatabaseInsightResourceUsage API.
     */
    summarizeDatabaseInsightResourceUsage(summarizeDatabaseInsightResourceUsageRequest: requests.SummarizeDatabaseInsightResourceUsageRequest): Promise<responses.SummarizeDatabaseInsightResourceUsageResponse>;
    /**
     * Returns response with time series data (endTimestamp, usage, capacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceUsageTrendRequest
     * @return SummarizeDatabaseInsightResourceUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeDatabaseInsightResourceUsageTrend.ts.html |here} to see how to use SummarizeDatabaseInsightResourceUsageTrend API.
     */
    summarizeDatabaseInsightResourceUsageTrend(summarizeDatabaseInsightResourceUsageTrendRequest: requests.SummarizeDatabaseInsightResourceUsageTrendRequest): Promise<responses.SummarizeDatabaseInsightResourceUsageTrendResponse>;
    /**
     * Gets resources with current utilization (high and low) and projected utilization (high and low) for a resource type over specified time period.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceUtilizationInsightRequest
     * @return SummarizeDatabaseInsightResourceUtilizationInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeDatabaseInsightResourceUtilizationInsight.ts.html |here} to see how to use SummarizeDatabaseInsightResourceUtilizationInsight API.
     */
    summarizeDatabaseInsightResourceUtilizationInsight(summarizeDatabaseInsightResourceUtilizationInsightRequest: requests.SummarizeDatabaseInsightResourceUtilizationInsightRequest): Promise<responses.SummarizeDatabaseInsightResourceUtilizationInsightResponse>;
    /**
     * Returns response with usage time series data (endTimestamp, usage, capacity) with breakdown by tablespaceName for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightTablespaceUsageTrendRequest
     * @return SummarizeDatabaseInsightTablespaceUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeDatabaseInsightTablespaceUsageTrend.ts.html |here} to see how to use SummarizeDatabaseInsightTablespaceUsageTrend API.
     */
    summarizeDatabaseInsightTablespaceUsageTrend(summarizeDatabaseInsightTablespaceUsageTrendRequest: requests.SummarizeDatabaseInsightTablespaceUsageTrendRequest): Promise<responses.SummarizeDatabaseInsightTablespaceUsageTrendResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity) for the time period specified for an exadata system for a resource metric.
     * Additionally resources can be filtered using databaseInsightId, hostInsightId or storageServerName query parameters.
     * Top five resources are returned if total exceeds the limit specified.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE. Database name is returned in name field. DatabaseInsightId, cdbName and hostName query parameter applies to ResourceType DATABASE.
     * Valid values for ResourceType HOST are CPU and MEMORY. HostName is returned in name field. HostInsightId and hostName query parameter applies to ResourceType HOST.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT. Storage server name is returned in name field for resourceMetric IOPS and THROUGHPUT
     * and asmName is returned in name field for resourceMetric STORAGE. StorageServerName query parameter applies to ResourceType STORAGE_SERVER.
     * Valid values for ResourceType DISKGROUP is STORAGE. Comma delimited (asmName,diskgroupName) is returned in name field.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceCapacityTrendRequest
     * @return SummarizeExadataInsightResourceCapacityTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeExadataInsightResourceCapacityTrend.ts.html |here} to see how to use SummarizeExadataInsightResourceCapacityTrend API.
     */
    summarizeExadataInsightResourceCapacityTrend(summarizeExadataInsightResourceCapacityTrendRequest: requests.SummarizeExadataInsightResourceCapacityTrendRequest): Promise<responses.SummarizeExadataInsightResourceCapacityTrendResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity) for the time period specified for an exadata system or fleet aggregation for a resource metric.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceCapacityTrendAggregatedRequest
     * @return SummarizeExadataInsightResourceCapacityTrendAggregatedResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeExadataInsightResourceCapacityTrendAggregated.ts.html |here} to see how to use SummarizeExadataInsightResourceCapacityTrendAggregated API.
     */
    summarizeExadataInsightResourceCapacityTrendAggregated(summarizeExadataInsightResourceCapacityTrendAggregatedRequest: requests.SummarizeExadataInsightResourceCapacityTrendAggregatedRequest): Promise<responses.SummarizeExadataInsightResourceCapacityTrendAggregatedResponse>;
    /**
     * Get historical usage and forecast predictions for an exadata system with breakdown by databases, hosts or storage servers.
     * Additionally resources can be filtered using databaseInsightId, hostInsightId or storageServerName query parameters.
     * Top five resources are returned if total exceeds the limit specified.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE. Database name is returned in name field. DatabaseInsightId , cdbName and hostName query parameter applies to ResourceType DATABASE.
     * Valid values for ResourceType HOST are CPU and MEMORY. HostName s returned in name field. HostInsightId and hostName query parameter applies to ResourceType HOST.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT. Storage server name is returned in name field for resourceMetric IOPS and THROUGHPUT
     * and asmName is returned in name field for resourceMetric STORAGE. StorageServerName query parameter applies to ResourceType STORAGE_SERVER.
     * Valid value for ResourceType DISKGROUP is STORAGE. Comma delimited (asmName,diskgroupName) is returned in name field.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceForecastTrendRequest
     * @return SummarizeExadataInsightResourceForecastTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeExadataInsightResourceForecastTrend.ts.html |here} to see how to use SummarizeExadataInsightResourceForecastTrend API.
     */
    summarizeExadataInsightResourceForecastTrend(summarizeExadataInsightResourceForecastTrendRequest: requests.SummarizeExadataInsightResourceForecastTrendRequest): Promise<responses.SummarizeExadataInsightResourceForecastTrendResponse>;
    /**
     * Get aggregated historical usage and forecast predictions for resources. Either compartmentId or exadataInsightsId query parameter must be specified.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceForecastTrendAggregatedRequest
     * @return SummarizeExadataInsightResourceForecastTrendAggregatedResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeExadataInsightResourceForecastTrendAggregated.ts.html |here} to see how to use SummarizeExadataInsightResourceForecastTrendAggregated API.
     */
    summarizeExadataInsightResourceForecastTrendAggregated(summarizeExadataInsightResourceForecastTrendAggregatedRequest: requests.SummarizeExadataInsightResourceForecastTrendAggregatedRequest): Promise<responses.SummarizeExadataInsightResourceForecastTrendAggregatedResponse>;
    /**
     * Lists the Resource statistics (usage, capacity, usage change percent, utilization percent) for each resource based on resourceMetric filtered by utilization level.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS, THROUGHPUT.
     * Valid value for ResourceType DISKGROUP is STORAGE.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceStatisticsRequest
     * @return SummarizeExadataInsightResourceStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeExadataInsightResourceStatistics.ts.html |here} to see how to use SummarizeExadataInsightResourceStatistics API.
     */
    summarizeExadataInsightResourceStatistics(summarizeExadataInsightResourceStatisticsRequest: requests.SummarizeExadataInsightResourceStatisticsRequest): Promise<responses.SummarizeExadataInsightResourceStatisticsResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per resource within the specified time period.
     * For each resource, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceUsageRequest
     * @return SummarizeExadataInsightResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeExadataInsightResourceUsage.ts.html |here} to see how to use SummarizeExadataInsightResourceUsage API.
     */
    summarizeExadataInsightResourceUsage(summarizeExadataInsightResourceUsageRequest: requests.SummarizeExadataInsightResourceUsageRequest): Promise<responses.SummarizeExadataInsightResourceUsageResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per database within the specified time period.
     * For each database, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceUsageAggregatedRequest
     * @return SummarizeExadataInsightResourceUsageAggregatedResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeExadataInsightResourceUsageAggregated.ts.html |here} to see how to use SummarizeExadataInsightResourceUsageAggregated API.
     */
    summarizeExadataInsightResourceUsageAggregated(summarizeExadataInsightResourceUsageAggregatedRequest: requests.SummarizeExadataInsightResourceUsageAggregatedRequest): Promise<responses.SummarizeExadataInsightResourceUsageAggregatedResponse>;
    /**
     * Gets current utilization, projected utilization and days to reach projectedUtilization for an exadata system over specified time period. Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE. Valid values for ResourceType HOST are CPU and MEMORY. Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceUtilizationInsightRequest
     * @return SummarizeExadataInsightResourceUtilizationInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeExadataInsightResourceUtilizationInsight.ts.html |here} to see how to use SummarizeExadataInsightResourceUtilizationInsight API.
     */
    summarizeExadataInsightResourceUtilizationInsight(summarizeExadataInsightResourceUtilizationInsightRequest: requests.SummarizeExadataInsightResourceUtilizationInsightRequest): Promise<responses.SummarizeExadataInsightResourceUtilizationInsightResponse>;
    /**
     * Lists the software and hardware inventory of the Exadata System.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataMembersRequest
     * @return SummarizeExadataMembersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeExadataMembers.ts.html |here} to see how to use SummarizeExadataMembers API.
     */
    summarizeExadataMembers(summarizeExadataMembersRequest: requests.SummarizeExadataMembersRequest): Promise<responses.SummarizeExadataMembersResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceCapacityTrendRequest
     * @return SummarizeHostInsightResourceCapacityTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeHostInsightResourceCapacityTrend.ts.html |here} to see how to use SummarizeHostInsightResourceCapacityTrend API.
     */
    summarizeHostInsightResourceCapacityTrend(summarizeHostInsightResourceCapacityTrendRequest: requests.SummarizeHostInsightResourceCapacityTrendRequest): Promise<responses.SummarizeHostInsightResourceCapacityTrendResponse>;
    /**
     * Get Forecast predictions for CPU or memory resources since a time in the past.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceForecastTrendRequest
     * @return SummarizeHostInsightResourceForecastTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeHostInsightResourceForecastTrend.ts.html |here} to see how to use SummarizeHostInsightResourceForecastTrend API.
     */
    summarizeHostInsightResourceForecastTrend(summarizeHostInsightResourceForecastTrendRequest: requests.SummarizeHostInsightResourceForecastTrendRequest): Promise<responses.SummarizeHostInsightResourceForecastTrendResponse>;
    /**
     * Lists the resource statistics (usage, capacity, usage change percent, utilization percent, load) for each host filtered
     * by utilization level in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceStatisticsRequest
     * @return SummarizeHostInsightResourceStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeHostInsightResourceStatistics.ts.html |here} to see how to use SummarizeHostInsightResourceStatistics API.
     */
    summarizeHostInsightResourceStatistics(summarizeHostInsightResourceStatisticsRequest: requests.SummarizeHostInsightResourceStatisticsRequest): Promise<responses.SummarizeHostInsightResourceStatisticsResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per host within the specified time period.
     * For each host, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceUsageRequest
     * @return SummarizeHostInsightResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeHostInsightResourceUsage.ts.html |here} to see how to use SummarizeHostInsightResourceUsage API.
     */
    summarizeHostInsightResourceUsage(summarizeHostInsightResourceUsageRequest: requests.SummarizeHostInsightResourceUsageRequest): Promise<responses.SummarizeHostInsightResourceUsageResponse>;
    /**
     * Returns response with time series data (endTimestamp, usage, capacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceUsageTrendRequest
     * @return SummarizeHostInsightResourceUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeHostInsightResourceUsageTrend.ts.html |here} to see how to use SummarizeHostInsightResourceUsageTrend API.
     */
    summarizeHostInsightResourceUsageTrend(summarizeHostInsightResourceUsageTrendRequest: requests.SummarizeHostInsightResourceUsageTrendRequest): Promise<responses.SummarizeHostInsightResourceUsageTrendResponse>;
    /**
     * Gets resources with current utilization (high and low) and projected utilization (high and low) for a resource type over specified time period.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceUtilizationInsightRequest
     * @return SummarizeHostInsightResourceUtilizationInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeHostInsightResourceUtilizationInsight.ts.html |here} to see how to use SummarizeHostInsightResourceUtilizationInsight API.
     */
    summarizeHostInsightResourceUtilizationInsight(summarizeHostInsightResourceUtilizationInsightRequest: requests.SummarizeHostInsightResourceUtilizationInsightRequest): Promise<responses.SummarizeHostInsightResourceUtilizationInsightResponse>;
    /**
     * Returns response with aggregated time series data (timeIntervalstart, timeIntervalEnd, commandArgs, usageData) for top processes.
     * Data is aggregated for the time period specified and proceses are sorted descendent by the proces metric specified (CPU, MEMORY, VIRTUAL_MEMORY).
     * HostInsight Id and Process metric must be specified
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightTopProcessesUsageTrendRequest
     * @return SummarizeHostInsightTopProcessesUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeHostInsightTopProcessesUsageTrend.ts.html |here} to see how to use SummarizeHostInsightTopProcessesUsageTrend API.
     */
    summarizeHostInsightTopProcessesUsageTrend(summarizeHostInsightTopProcessesUsageTrendRequest: requests.SummarizeHostInsightTopProcessesUsageTrendRequest): Promise<responses.SummarizeHostInsightTopProcessesUsageTrendResponse>;
    /**
     * Gets the details of resources used by an Operations Insights Warehouse.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeOperationsInsightsWarehouseResourceUsageRequest
     * @return SummarizeOperationsInsightsWarehouseResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeOperationsInsightsWarehouseResourceUsage.ts.html |here} to see how to use SummarizeOperationsInsightsWarehouseResourceUsage API.
     */
    summarizeOperationsInsightsWarehouseResourceUsage(summarizeOperationsInsightsWarehouseResourceUsageRequest: requests.SummarizeOperationsInsightsWarehouseResourceUsageRequest): Promise<responses.SummarizeOperationsInsightsWarehouseResourceUsageResponse>;
    /**
     * Query SQL Warehouse to get the performance insights for SQLs taking greater than X% database time for a given
     * time period across the given databases or database types in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlInsightsRequest
     * @return SummarizeSqlInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeSqlInsights.ts.html |here} to see how to use SummarizeSqlInsights API.
     */
    summarizeSqlInsights(summarizeSqlInsightsRequest: requests.SummarizeSqlInsightsRequest): Promise<responses.SummarizeSqlInsightsResponse>;
    /**
     * Query SQL Warehouse to get the performance insights on the execution plans for a given SQL for a given time period.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlPlanInsightsRequest
     * @return SummarizeSqlPlanInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeSqlPlanInsights.ts.html |here} to see how to use SummarizeSqlPlanInsights API.
     */
    summarizeSqlPlanInsights(summarizeSqlPlanInsightsRequest: requests.SummarizeSqlPlanInsightsRequest): Promise<responses.SummarizeSqlPlanInsightsResponse>;
    /**
     * Query SQL Warehouse to summarize the response time distribution of query executions for a given SQL for a given time period.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlResponseTimeDistributionsRequest
     * @return SummarizeSqlResponseTimeDistributionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeSqlResponseTimeDistributions.ts.html |here} to see how to use SummarizeSqlResponseTimeDistributions API.
     */
    summarizeSqlResponseTimeDistributions(summarizeSqlResponseTimeDistributionsRequest: requests.SummarizeSqlResponseTimeDistributionsRequest): Promise<responses.SummarizeSqlResponseTimeDistributionsResponse>;
    /**
     * Query SQL Warehouse to get the performance statistics for SQLs taking greater than X% database time for a given
     * time period across the given databases or database types in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlStatisticsRequest
     * @return SummarizeSqlStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeSqlStatistics.ts.html |here} to see how to use SummarizeSqlStatistics API.
     */
    summarizeSqlStatistics(summarizeSqlStatisticsRequest: requests.SummarizeSqlStatisticsRequest): Promise<responses.SummarizeSqlStatisticsResponse>;
    /**
     * Query SQL Warehouse to get the performance statistics time series for a given SQL across given databases for a
     * given time period in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlStatisticsTimeSeriesRequest
     * @return SummarizeSqlStatisticsTimeSeriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeSqlStatisticsTimeSeries.ts.html |here} to see how to use SummarizeSqlStatisticsTimeSeries API.
     */
    summarizeSqlStatisticsTimeSeries(summarizeSqlStatisticsTimeSeriesRequest: requests.SummarizeSqlStatisticsTimeSeriesRequest): Promise<responses.SummarizeSqlStatisticsTimeSeriesResponse>;
    /**
     * Query SQL Warehouse to get the performance statistics time series for a given SQL by execution plans for a given time period.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlStatisticsTimeSeriesByPlanRequest
     * @return SummarizeSqlStatisticsTimeSeriesByPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/SummarizeSqlStatisticsTimeSeriesByPlan.ts.html |here} to see how to use SummarizeSqlStatisticsTimeSeriesByPlan API.
     */
    summarizeSqlStatisticsTimeSeriesByPlan(summarizeSqlStatisticsTimeSeriesByPlanRequest: requests.SummarizeSqlStatisticsTimeSeriesByPlanRequest): Promise<responses.SummarizeSqlStatisticsTimeSeriesByPlanResponse>;
    /**
     * Updates the configuration of a hub .
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAwrHubRequest
     * @return UpdateAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/UpdateAwrHub.ts.html |here} to see how to use UpdateAwrHub API.
     */
    updateAwrHub(updateAwrHubRequest: requests.UpdateAwrHubRequest): Promise<responses.UpdateAwrHubResponse>;
    /**
     * Updates configuration of a database insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDatabaseInsightRequest
     * @return UpdateDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/UpdateDatabaseInsight.ts.html |here} to see how to use UpdateDatabaseInsight API.
     */
    updateDatabaseInsight(updateDatabaseInsightRequest: requests.UpdateDatabaseInsightRequest): Promise<responses.UpdateDatabaseInsightResponse>;
    /**
     * Updates configuration of an Operations Insights Enterprise Manager bridge.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateEnterpriseManagerBridgeRequest
     * @return UpdateEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/UpdateEnterpriseManagerBridge.ts.html |here} to see how to use UpdateEnterpriseManagerBridge API.
     */
    updateEnterpriseManagerBridge(updateEnterpriseManagerBridgeRequest: requests.UpdateEnterpriseManagerBridgeRequest): Promise<responses.UpdateEnterpriseManagerBridgeResponse>;
    /**
     * Updates configuration of an Exadata insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateExadataInsightRequest
     * @return UpdateExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/UpdateExadataInsight.ts.html |here} to see how to use UpdateExadataInsight API.
     */
    updateExadataInsight(updateExadataInsightRequest: requests.UpdateExadataInsightRequest): Promise<responses.UpdateExadataInsightResponse>;
    /**
     * Updates configuration of a host insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateHostInsightRequest
     * @return UpdateHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/UpdateHostInsight.ts.html |here} to see how to use UpdateHostInsight API.
     */
    updateHostInsight(updateHostInsightRequest: requests.UpdateHostInsightRequest): Promise<responses.UpdateHostInsightResponse>;
    /**
     * Updates one or more attributes of the specified private endpoint.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOperationsInsightsPrivateEndpointRequest
     * @return UpdateOperationsInsightsPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/UpdateOperationsInsightsPrivateEndpoint.ts.html |here} to see how to use UpdateOperationsInsightsPrivateEndpoint API.
     */
    updateOperationsInsightsPrivateEndpoint(updateOperationsInsightsPrivateEndpointRequest: requests.UpdateOperationsInsightsPrivateEndpointRequest): Promise<responses.UpdateOperationsInsightsPrivateEndpointResponse>;
    /**
     * Updates the configuration of an Operations Insights Warehouse.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOperationsInsightsWarehouseRequest
     * @return UpdateOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/UpdateOperationsInsightsWarehouse.ts.html |here} to see how to use UpdateOperationsInsightsWarehouse API.
     */
    updateOperationsInsightsWarehouse(updateOperationsInsightsWarehouseRequest: requests.UpdateOperationsInsightsWarehouseRequest): Promise<responses.UpdateOperationsInsightsWarehouseResponse>;
    /**
     * Updates the configuration of an Operations Insights Warehouse User.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOperationsInsightsWarehouseUserRequest
     * @return UpdateOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.37.0/opsi/UpdateOperationsInsightsWarehouseUser.ts.html |here} to see how to use UpdateOperationsInsightsWarehouseUser API.
     */
    updateOperationsInsightsWarehouseUser(updateOperationsInsightsWarehouseUserRequest: requests.UpdateOperationsInsightsWarehouseUserRequest): Promise<responses.UpdateOperationsInsightsWarehouseUserResponse>;
}
